#
# spec file for package deja-dup
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           deja-dup
Version:        34.3
Release:        0
# FIXME: reenable "make check" in %%check, when lp#940110 is fixed
Summary:        Simple backup tool and frontend for duplicity
License:        GPL-3.0+
Group:          Productivity/Archiving/Backup
Url:            https://launchpad.net/deja-dup
Source0:        https://launchpad.net/deja-dup/34/%{version}/+download/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE deja-dup-help2man_stderr.patch sfalken@opensuse.org -- fixes help2man failure in build
Patch0:         deja-dup-help2man_stderr.patch
# For make check to work, we need dbus-launch
BuildRequires:  cmake
BuildRequires:  dbus-1-x11
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  perl-gettext
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.16.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(libnautilus-extension)
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(packagekit-glib2)
Recommends:     duplicity >= 0.6.25
Recommends:     %{name}-lang
Recommends:     python-boto
Recommends:     python-cloudfiles
%glib2_gsettings_schema_requires

%description
Déjà  Dup is a simple backup tool. It hides the complexity of doing
backups the 'right way' (encrypted, off-site, and regular) and uses
duplicity as the backend.

Features:
 * Support for local or remote backup locations, including Amazon S3
 * Securely encrypts and compresses your data
 * Incrementally backs up, letting you restore from any particular backup
 * Schedules regular backups
 * Integrates well into your GNOME desktop

%package -n nautilus-deja-dup
Summary:        Déjà Dup Plugin for Nautilus
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:nautilus}

%description -n nautilus-deja-dup
Déjà  Dup is a simple backup tool. It hides the complexity of doing
backups the 'right way' (encrypted, off-site, and regular) and uses
duplicity as the backend.

Features:
 * Support for local or remote backup locations, including Amazon S3
 * Securely encrypts and compresses your data
 * Incrementally backs up, letting you restore from any particular backup
 * Schedules regular backups
 * Integrates well into your GNOME desktop

This package contains a plugin to integrate Déjà Dup into Nautilus.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="%{optflags} -Wl,-rpath=%{_libdir}/%{name}"
export CXXFLAGS="%{optflags} -Wl,-rpath=%{_libdir}/%{name}"
%cmake \
 -DENABLE_NAUTILUS=ON \
 -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
 -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir}
%__make %{?_smp_mflags}

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file deja-dup
%suse_update_desktop_file deja-dup-monitor
%suse_update_desktop_file -r deja-dup-preferences GTK GNOME System Archiving X-SuSE-Backup
%find_lang %{name} %{?no_lang_C}
# Localized man pages
for man in %{buildroot}%{_mandir}/*/man1/*; do
    LOCALE=`echo $man | sed "s:.*%{_mandir}/\([^/]*\)/man1/.*:\1:g"`
    echo "%%lang($LOCALE) %%dir %%{_mandir}/$LOCALE" >> %{name}.man-lang.tmp
    echo "%%lang($LOCALE) %%dir %%{_mandir}/$LOCALE/man1" >> %{name}.man-lang.tmp
    echo "%%lang($LOCALE) %%doc /${man##%{buildroot}}*" >> %{name}.man-lang.tmp
done
sort -u %{name}.man-lang.tmp > %{name}.man-lang
rm %{name}.man-lang.tmp
# create symlinks for man pages
%fdupes -s %{buildroot}%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}

%check
# FIXME: disabled because of lp#940110
#make check

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.man-lang
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/deja-dup
%{_bindir}/deja-dup-preferences
%{_mandir}/man1/deja-dup.*
%{_mandir}/man1/deja-dup-preferences.*
%{_sysconfdir}/xdg/autostart/deja-dup-monitor.desktop
# We explicitly list the content of %%{_libexecdir}/deja-dup to make sure we
# put the files in the right subpackage
%dir %{_libexecdir}/deja-dup
%{_libexecdir}/deja-dup/deja-dup-monitor
%{_libexecdir}/deja-dup/tools/
%{_datadir}/applications/deja-dup.desktop
%{_datadir}/applications/deja-dup-preferences.desktop
%{_datadir}/%{name}/
%{_datadir}/GConf/gsettings/deja-dup.convert
%{_datadir}/glib-2.0/schemas/org.gnome.DejaDup.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/deja-dup-symbolic.svg
%{_datadir}/icons/hicolor/scalable/devices/deja-dup-cloud.svg
%{_datadir}/icons/hicolor/*/apps/deja-dup.png
%dir %{_libdir}/deja-dup
%{_libdir}/deja-dup/libdeja.so
%{_libdir}/deja-dup/libwidgets.so
%dir %{_datadir}/appdata/
%{_datadir}/appdata/deja-dup.appdata.xml

%files -n nautilus-deja-dup
%defattr(-,root,root)
%{_libdir}/nautilus/extensions-3.0/libdeja-dup.so

%files lang -f %{name}.lang

%changelog
